==> gnumeric-1.1.0.tar.bz2: gnumeric-1.1.0/src/gnm-marshalers.h <==

#ifndef __gnm__MARSHAL_H__
#define __gnm__MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:POINTER (gnm-marshalers.list:23) */
extern void gnm__BOOLEAN__POINTER (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* INT:INT (gnm-marshalers.list:24) */
extern void gnm__INT__INT (GClosure     *closure,
                           GValue       *return_value,
                           guint         n_param_values,
                           const GValue *param_values,
                           gpointer      invocation_hint,
                           gpointer      marshal_data);

/* NONE:INT,INT (gnm-marshalers.list:25) */
extern void gnm__VOID__INT_INT (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);
#define gnm__NONE__INT_INT	gnm__VOID__INT_INT

/* NONE:NONE (gnm-marshalers.list:26) */
#define gnm__VOID__VOID	g_cclosure_marshal_VOID__VOID
#define gnm__NONE__NONE	gnm__VOID__VOID

/* NONE:POINTER (gnm-marshalers.list:27) */
#define gnm__VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define gnm__NONE__POINTER	gnm__VOID__POINTER

/* POINTER:INT,INT (gnm-marshalers.list:28) */
extern void gnm__POINTER__INT_INT (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

G_END_DECLS

#endif /* __gnm__MARSHAL_H__ */

==> gnumeric-1.1.16.tar.bz2: gnumeric-1.1.16/src/gnm-marshalers.h <==

#ifndef __gnm__MARSHAL_H__
#define __gnm__MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:POINTER (gnm-marshalers.list:23) */
extern void gnm__BOOLEAN__POINTER (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* INT:INT (gnm-marshalers.list:24) */
extern void gnm__INT__INT (GClosure     *closure,
                           GValue       *return_value,
                           guint         n_param_values,
                           const GValue *param_values,
                           gpointer      invocation_hint,
                           gpointer      marshal_data);

/* POINTER:INT,INT (gnm-marshalers.list:25) */
extern void gnm__POINTER__INT_INT (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* NONE:INT,INT (gnm-marshalers.list:26) */
extern void gnm__VOID__INT_INT (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);
#define gnm__NONE__INT_INT	gnm__VOID__INT_INT

/* NONE:NONE (gnm-marshalers.list:27) */
#define gnm__VOID__VOID	g_cclosure_marshal_VOID__VOID
#define gnm__NONE__NONE	gnm__VOID__VOID

/* NONE:POINTER (gnm-marshalers.list:28) */
#define gnm__VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define gnm__NONE__POINTER	gnm__VOID__POINTER

/* NONE:OBJECT (gnm-marshalers.list:29) */
#define gnm__VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
#define gnm__NONE__OBJECT	gnm__VOID__OBJECT

/* NONE:STRING (gnm-marshalers.list:30) */
#define gnm__VOID__STRING	g_cclosure_marshal_VOID__STRING
#define gnm__NONE__STRING	gnm__VOID__STRING

G_END_DECLS

#endif /* __gnm__MARSHAL_H__ */
